{% extends "bee_django_user/base.html" %}

{% block content %}
    <h3>后台管理</h3>

    <div><a href="{% url 'bee_django_crm:index' %}">crm</a></div>
    <div><a href="{% url 'bee_django_user:index' %}">学生</a></div>



{% endblock %}