{% extends 'bee_django_user/base.html' %}
{% load bootstrap3 %}
{% load static %}

{% block content %}
        <div>

            <form method="post">
                {% csrf_token %}
                {% bootstrap_form form %}
                <input type="submit" value="重置">
                <!-- <a href="#">课程卡注册</a> -->
            </form>
        </div>
{% endblock content %}