{% extends "bee_django_user/base.html" %}
{% load bee_django_user_filter %}
{% block content %}
    {% include 'bee_django_user/logo.html' %}
    {% include 'bee_django_user/nav.html' %}
    {% include 'bee_django_user/messages.html' %}
    <h4>学生详情</h4>
    <table class="table">
        <tr>
            <td class="col-xs-3">姓名</td>
            <td>{{ preuser.name }}</td>
        </tr>



    </table>
{% endblock %}