{#{% if perms.bee_django_user.change_userprofile %}#}
{#        <a href="{% url 'bee_django_user:user_update'  user.id %}">修改</a>#}
{#    {% endif %}#}
<table class="table">
    <tr>
        <td class="col-xs-3">姓名</td>
        <td>{{ record.user.first_name }}</td>
    </tr>
    <tr>
        <td>请假类型</td>
        <td>{{ record.get_type }}</td>
    </tr>
    <tr>
        <td>{% if record.type == 1 or record.type == 2 %}请假{% endif %}开始日期</td>
        <td>{{ record.start|default:"" }}</td>
    </tr>
    <tr>
        <td>{% if record.type == 1 or record.type == 2 %}请假{% endif %}结束日期</td>
        <td>{{ record.end|default:"" }}</td>
    </tr>
    <tr>
        <td>原结课日期</td>
        <td><span style="color: red">{{ record.old_expire|default:"" }}</span></td>
    </tr>
    <tr>
        <td>新结课日期</td>
        <td><span style="color: red">{{ record.new_expire }}</span></td>
    </tr>
    <tr>
        <td>备注</td>
        <td>{{ record.info|safe|linebreaks|default:"" }}</td>
    </tr>
    <tr>
        <td>添加</td>
        <td>已由【{{ record.created_by.first_name }}】于{{ record.created_at }}添加</td>
    </tr>
    <tr>
        <td>审核</td>
        <td>
            {% include 'bee_django_user/leave/_check.html' %}

        </td>
    </tr>
    <tr>
        <td>操作</td>
        <td>{% include 'bee_django_user/leave/_cancel.html' %}</td>
    </tr>


</table>
